@@ -1,5 +1,5 @@
 /* --------------------------------------------------------------------------
- * Copyright 2003-2011 (inclusive) Nathan Angelacos 
+ * Copyright 2003-2014 (inclusive) Nathan Angelacos 
  *                   (nangel@users.sourceforge.net)
  * 
  *   This file is part of haserl.
@@ -31,6 +31,7 @@
 #include <fcntl.h>
 
 #include "sliding_buffer.h"
+#include "h_error.h"
 
 /*
  * initialize a sliding buffer structure 
@@ -128,27 +129,37 @@ s_buffer_read (sliding_buffer_t * sbuf, char *matchstr)
    */
   pos = 0;
   len = sbuf->bufsize - (int) (sbuf->ptr - sbuf->buf) - strlen (matchstr);
-  while (memcmp (matchstr, sbuf->ptr + pos, strlen (matchstr)) && (pos < len))
-    {
-      pos++;
-    }
+  /* a malicious client can send a matchstr longer than the actual content body 
+     do not allow reads beyond the buffer limits
+  */
+  len = ( len < 0 ) ? 0 : len;
 
-  /*
-   * if we found it 
-   */
-  if (pos < len)
-    {
-      sbuf->len = pos;
-      sbuf->segment = sbuf->ptr;
-      sbuf->ptr = sbuf->segment + pos + strlen (matchstr);
-      return -1;
-    }
+  /* if have a matchstr, look for it, otherwise return the chunk */
+  if ( strlen(matchstr) > 0 )  {
 
-  if (sbuf->eof)
-    {
-      len += strlen (matchstr);
-    }
+	  while (memcmp (matchstr, sbuf->ptr + pos, strlen (matchstr)) && (pos < len))
+	    {
+	      pos++;
+	    }
 
+	  /*
+	   * if we found it 
+	   */
+	  if (pos < len)
+	    {
+	      sbuf->len = pos;
+	      sbuf->segment = sbuf->ptr;
+	      sbuf->ptr = sbuf->segment + pos + strlen (matchstr);
+	      return -1;
+	    }
+	
+
+	  if (sbuf->eof)
+	    {
+	      len += strlen (matchstr);
+	    }
+
+  } 
   /*
    * ran off the end, didn't find the matchstr
    */
